Skip to main contentModule context
Source - BuildContext
- Context passed at the start of a build.
- ContentContext
- Context passed after a single content file is parsed.
- GraphContext
- Context passed after all content is ingested into the graph.
- InitContext
- Context passed to plugins during initialization.
- OutputContext
- Context passed after all output files are written.
- PageData
- Plugin-facing view of a page’s parsed content.
- RenderContext
- Context passed before rendering a single page.
- ValidationContext
- Context passed after SHACL validation completes.
- WatchContext
- Context passed when a file change is detected during
serve.